<?php
/**
 * Create the templatic advanced search widget.
 *
 * @package Wordpress
 * @subpackage Tevolution
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Advance Search Widget Class.
 **/
class Templatic_Advanced_Search extends WP_Widget {
	/**
	 * Set up the widget's unique name, ID, class, description, and other options.
	 */
	function __construct() {
		/*Constructor*/
		$widget_ops = array(
			'classname' => 'templatic-advanced-search',
			'description' => __( 'Display search fields for a specific post type. Custom fields selected to show inside the Advanced search form will also show inside this widget. Works best in sidebar areas. ',
			'templatic-admin' ),
			'before_widget' => '<div class="column_wrap">',
			);
		parent::__construct( 'templatic_advanced_search', __( 'T &rarr; Advanced Search', 'templatic-admin' ), $widget_ops );
	}
	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @param array $args 		agurment of widget area.
	 * @param array $instance 	instances of widget.
	 */
	function widget( $args, $instance ) {
		/* prints the widget*/
		extract( $args, EXTR_SKIP );

		global $wp_locale, $search_id;

		$title = empty( $instance['title'] ) ? '' : apply_filters( 'widget_title', $instance['title'] );
		$post_type = empty( $instance['post_type'] ) ? 'post' : apply_filters( 'widget_post_type', $instance['post_type'] );
		$search_custom_fields = empty( $instance['search_custom_fields'] ) ? array() : apply_filters( 'widget_search_custom_fields', $instance['search_custom_fields'] );
		$search_ctype = empty( $instance['search_ctype'] ) ? array() : apply_filters( 'widget_search_ctype', $instance['search_ctype'] );
		$orderby_customfields = empty( $instance['orderby_customfields'] ) ? array() : apply_filters( 'widget_orderby_customfields', array_unique( $instance['orderby_customfields'] ) );

		echo wp_kses_post( wp_unslash( $args['before_widget'] ) );

		/* get widget id from custom field as per ajax */
		$search_instance = explode( '-', $args['widget_id'] );
		$search_id = $search_instance[1];

		if ( function_exists( 'icl_register_string' ) ) {
			icl_register_string( 'templatic', 'templatic_about_title' . $title, $title );
			$title = icl_t( 'templatic', 'templatic_about_title' . $title, $title );
		}
		if ( '' <> $title ) {
			echo wp_kses_post( wp_unslash( $args['before_title'] . $title . $args['after_title'] ) );
		}

		/* include datepicker js file */
		wp_enqueue_script( 'jquery-ui-datepicker' );
		/*localize our js*/
		$aryArgs = array(
			'monthNames'    => strip_array_indices( $wp_locale->month ),
			'monthNamesShort'  => strip_array_indices( $wp_locale->month_abbrev ),
			'monthStatus'    => __( 'Show a different month', 'templatic' ),
			'dayNames'     => strip_array_indices( $wp_locale->weekday ),
			'dayNamesShort'   => strip_array_indices( $wp_locale->weekday_abbrev ),
			'dayNamesMin'    => strip_array_indices( $wp_locale->weekday_initial ),
			/* is Right to left language? default is false*/
			'isRTL'       => (isset( $wp_locale->is_rtl ) ) ? $wp_locale->is_rtl :'',
			);

		/* Pass the array to the enqueued JS*/
		wp_localize_script( 'jquery-ui-datepicker', 'objectL11tmpl', $aryArgs );

		?>
		<form method="get" id="searchform" action="<?php echo esc_url( home_url( '/' ) ); ?>" class="form_front_style">
			<div class="form_row clearfix search_keyword">
				<?php do_action( 'tmpl_advance_search_label' );?>
				<input class="adv_input" name="s" id="adv_s" type="text" PLACEHOLDER="<?php esc_html_e( 'Search', 'templatic' ); ?>" value="" />
				<span class="message_error2" style="color:red;font-size:12px;" id="search_error"></span>
			</div>
			<?php
			global $wpdb;
			$post_category = $wpdb->get_row( "SELECT post_title,ID FROM $wpdb->posts WHERE $wpdb->posts.post_name = 'category' and $wpdb->posts.post_type = 'custom_fields'" );
			global $is_category;
			$is_category = 0;
			$tmpdata = get_option( 'templatic_settings' );
			$category_specific_search_fields = @$tmpdata['templatic-category_custom_search_fields'];
			if ( in_array( $post_category->ID, $orderby_customfields ) && 'Yes' == $category_specific_search_fields ) {
				$is_category = 1;
			}

			if ( ! empty( $orderby_customfields ) && is_array( $orderby_customfields ) ) {

				foreach ( $orderby_customfields as $value ) {

					if ( $is_category == 1 && $value == $post_category ->ID ) {
						display_search_widget_custom_post_fields( $value, $instance,0 );
					} elseif ( 0 == $is_category ) {
						display_search_widget_custom_post_fields( $value, $instance,0 );
					} else {
						continue;
					}
				} // End foreach().
			} // End if().
			?>
			<div id="search_result"></div>
			<input type="hidden" name="search_template" value="1"/>
			<!--<input class="adv_input" name="adv_search" id="adv_search" type="hidden" value="1" />-->
			<input class="adv_input" name="post_type" id="post_type" type="hidden" value="<?php echo wp_kses_post( wp_unslash( $post_type ) ); ?>" />
			<input type="submit" name="submit" value="<?php apply_filters( 'tmpl_advance_search_submit_label', esc_html_e( 'Search', 'templatic' ) ); ?>" class="adv_submit" onclick="return set_adv_search();"/>
		</form>
		<?php
		echo wp_kses_post( wp_unslash( $args['after_widget'] ) );
	}
	/**
	 *
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @param array $new_instance     new instance of widget when saved from widget area.
	 * @param array $old_instance 	  old instances of widget.
	 */
	function update( $new_instance, $old_instance ) {
		/*save the widget*/
		$new_instance['orderby_customfields'] = array_unique( $new_instance['orderby_customfields'] );
		return $new_instance;
	}
	/**
	 *
	 * Save the widget.
	 *
	 * @param array $instance     instance of widget.
	 */
	function form( $instance ) {
		/*widgetform in backend*/
		global $search_custom_fields_instance;
		$instance = wp_parse_args( (array) $instance, array(
			'title' => '',
			'post_type' => '',
			'search_custom_fields' => '',
			'search_ctype' => '',
			'orderby_customfields' => '',
			)
		);
		$title = ( $instance['title'] ) ? $instance['title'] : __( 'Advanced Search', 'templatic-admin' );
		$current_post_type = ( $instance['post_type'] ) ? $instance['post_type'] : 'post';

		/*global set advance search widget instance */
		$search_custom_fields_instance = $instance;
		$search_custom_fields = $this->get_field_name( 'search_custom_fields' );
		$search_ctype = $this->get_field_name( 'search_ctype' );
		$orderby_customfields = $this->get_field_name( 'orderby_customfields' );
		?>
		<p>
			<label for="<?php echo wp_kses_post( wp_unslash( $this ->get_field_id( 'title' ) ) ); ?>"><?php echo esc_html__( 'Title:', 'templatic-admin' );?>
				<input class="widefat" id="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'title' ) ) ); ?>" name="<?php echo wp_kses_post( wp_unslash( $this->get_field_name( 'title' ) ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</label>
		</p>
		<p>
			<label for="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'post_type' ) ) );?>" ><?php echo esc_html__( 'Post Type:', 'templatic-admin' );?>   </label>
			<select id="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'post_type' ) ) ); ?>" name="<?php echo wp_kses_post( wp_unslash( $this->get_field_name( 'post_type' ) ) ); ?>" class="widefat" onchange="tmpl_search_post_type(this, '<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'custom_fields_lists' ) ) ); ?>', '<?php echo wp_kses_post( wp_unslash( $search_custom_fields ) );?>', '<?php echo wp_kses_post( wp_unslash( $search_ctype ) );?>', '<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'search_custom_fields' ) ) ); ?>', '<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'custom_fields_lists' ) ) )?>' );">
				<option value="post"><?php esc_html_e( 'Post', 'templatic' );?></option>
				<?php
				$all_post_types = get_option( 'templatic_custom_post' );
				foreach ( $all_post_types as $key => $post_type ) {
					if ( 'admanager' == $key ) {
						continue;
					}
					?>
					<option value="<?php echo wp_kses_post( wp_unslash( $key ) );?>" <?php if ( $key == $current_post_type ) { echo 'selected="selected"';}?>><?php echo esc_attr( $post_type['label'] );?></option>
					<?php }?>
				</select>
				<span class="description"><?php echo esc_html__( 'Select the post type you wish to display on an advanced search form. ', 'templatic-admin' );?></span>
			</p>


			<span><label for="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'search_field' ) ) );?>" ><?php echo esc_html__( 'Search Field:', 'templatic-admin' );?>   </label></span>
			<div id="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'custom_fields_lists' ) ) ); ?>" class="custom_fields_list dropdown <?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'custom_fields_lists' ) ) ); ?>" data-class="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'search_custom_fields' ) ) );?>" data-order="<?php echo wp_kses_post( wp_unslash( $orderby_customfields ) );?>">
				<?php
				if ( $current_post_type ) {
					echo wp_kses_post( wp_unslash( tmpl_advance_search_custom_fields( $current_post_type, $search_custom_fields, $search_ctype, $this->get_field_id( 'search_custom_fields' ), $this->get_field_id( 'custom_fields_lists' ) ) ) );
				}
				?>
			</div>
			<p class="description"><?php echo esc_html__( 'Select custom field to display selected custom fields on frontend. ', 'templatic-admin' );?></p>
			<br class="clear">

			<div class="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'search_custom_fields' ) ) ); ?> advance_search_custom_fields" id="<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'search_custom_fields' ) ) ); ?>">
				<?php
				if ( ! empty( $instance['orderby_customfields'] ) && is_array( $instance['orderby_customfields'] ) ) :
					foreach ( array_unique( $instance['orderby_customfields'] ) as $k => $value ) {
						$key = $value;
						$ctype = get_post_meta( $key, 'ctype',true );
						/* condition is for older php version. otherwise it creates fatal error */
						if ( ! empty( $instance['search_ctype'] ) ) :
							$search_ctype_val = $instance['search_ctype'][ $key ]['search_ctype'];
							$option_title = $instance['search_ctype'][ $key ]['option_title'];
							$option_values = $instance['search_ctype'][ $key ]['option_values'];

							$min_option_title = $instance['search_ctype'][ $key ]['min_option_title'];
							$min_option_values = $instance['search_ctype'][ $key ]['min_option_values'];
							$max_option_title = $instance['search_ctype'][ $key ]['max_option_title'];
							$max_option_values = $instance['search_ctype'][ $key ]['max_option_values'];
							$range_min = $instance['search_ctype'][ $key ]['range_min'];
							$range_max = $instance['search_ctype'][ $key ]['range_max'];
						endif;
						?>
						<div class="widget <?php echo 'custom_' . wp_kses_post( wp_unslash( $this ->get_field_id( 'search_custom_fields' ) ) ) . '_' . wp_kses_post( wp_unslash( $key ) ); ?>" id="search_custom_field_<?php echo wp_kses_post( wp_unslash( $key ) ); ?>" data-sort="<?php echo wp_kses_post( wp_unslash( $key ) );?>">
							<input type="hidden" value="<?php echo wp_kses_post( wp_unslash( $key ) );?>" name="<?php echo wp_kses_post( wp_unslash( $orderby_customfields ) ); ?>[]">
							<div class="widget-top">
								<div class="widget-title-action">
									<a class="widget-action hide-if-no-js" href="#available-widgets"></a>
								</div>
								<div class="widget-title">
									<h4><?php echo wp_kses_post( wp_unslash( get_the_title( $key ) ) );?></h4>
								</div><!--Finish widget-title div-->
							</div><!--Finish widget-top div-->
							<?php
							echo '<div class="widget-inside">';
							if ( 'post_categories' == $ctype || 'multicity' == $ctype || 'geo_map' == $ctype || 'date' == $ctype ) {

								echo "<input type='hidden' value='" . wp_kses_post( wp_unslash( $ctype ) ) . "' name='" . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . "][search_ctype]'>";

								if ( 'geo_map' == $ctype && is_plugin_active( 'Tevolution-LocationManager/location-manager.php' ) ) {
									if ( ! empty( $instance['search_ctype'] ) ) :
										$radius_measure = $instance['search_ctype'][ $key ]['radius_measure'];
										$miles_search = $instance['search_ctype'][ $key ]['miles_search'];
										echo '<p><label><input name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][miles_search]" type="checkbox" value="1" style="width:10px;" ' . (( '1' == $miles_search )? 'checked':'' ) . ' />' . esc_html__( 'Search By Distance?', 'templatic-admin' ) . '</label>';
										echo '<p><label>' . esc_html__( 'Search By', 'templatic-admin' ) . '
									<select name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][radius_measure]">
										<option value="kilometer" ' . (( 'kilometer' == $radius_measure )? 'selected':'' ) . '>' . esc_html__( 'Kilometers', 'templatic-admin' ) . '</option>
										<option value="miles" ' . (( 'miles' == $radius_measure )? 'selected':'' ) . '>' . esc_html__( 'Miles', 'templatic-admin' ) . '</option>
									</select>
								</p>';
								endif;
								}
							} else {
								/*Disable search type option */
								$text = $date = $multicheckbox = $radio = $select = $min_max_range = $min_max_range_select = $slider_range = '';
								if ( 'text' == $ctype || 'textarea' == $ctype || 'texteditor' == $ctype ) {
									$date = $multicheckbox = $radio = $select = $min_max_range = $min_max_range_select = $slider_range = 'disabled';
								} elseif ( 'multicheckbox' == $ctype || 'select' == $ctype || 'radio' == $ctype ) {
									$date = $text = $min_max_range = $min_max_range_select = $slider_range = 'disabled';
								} elseif ( 'range_type' == $ctype ) {
									$text = $date = $multicheckbox = $radio = $select = 'disabled';
								}
								if ( 'text' == $ctype ) {
									$select = '';
								}

								echo '<p><label>' . esc_html__( 'Show on search as', 'templatic-admin' ) . '</label>';
								echo "<select name='" . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . "][search_ctype]' class='search_ctype_" . wp_kses_post( wp_unslash( $key ) ) . " search_custom_ctype' data-post-id='" . wp_kses_post( wp_unslash( $key ) ) . "' onchange='select_search_type_option(this);' data-search-type='" . wp_kses_post( wp_unslash( $ctype ) ) . "'>";
								echo '<option value="" >' . esc_html__( 'Select type on search', 'templatic-admin' ) . '</option>';
								echo '<option ' . wp_kses_post( wp_unslash( $text ) ) . ' value="text" ' . (( 'text' == wp_kses_post( wp_unslash( $search_ctype_val ) ) ) ? 'selected':'' ) . '>' . esc_html__( 'Text', 'templatic-admin' ) . '</option>';
								/*echo '<option ' . $date. ' value="date">' . esc_html__( 'Date Picker', 'templatic-admin' ). '</option>';*/
								echo '<option ' . wp_kses_post( wp_unslash( $multicheckbox ) ) . ' value="multicheckbox" ' . (( 'multicheckbox' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? 'selected':'' ) . '>' . esc_html__( 'Multi Checkbox', 'templatic-admin' ) . '</option>';
								echo '<option ' . wp_kses_post( wp_unslash( $radio ) ) . ' value="radio" ' . (( 'radio' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? 'selected':'' ) . '>' . esc_html__( 'Radio', 'templatic-admin' ) . '</option>';
								echo '<option ' . wp_kses_post( wp_unslash( $select ) ) . ' value="select" ' . (( 'select' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? 'selected':'' ) . '>' . esc_html__( 'Select', 'templatic-admin' ) . '</option>';
								echo '<option ' . wp_kses_post( wp_unslash( $min_max_range ) ) . ' value="min_max_range" ' . (( 'min_max_range' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? 'selected':'' ) . '>' . esc_html__( 'Min-Max Range (Text)', 'templatic-admin' ) . '</option>';
								echo '<option ' . wp_kses_post( wp_unslash( $min_max_range_select ) ) . ' value="min_max_range_select" ' . (( 'min_max_range_select' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? 'selected':'' ) . '>' . esc_html__( 'Min-Max Range (Select)', 'templatic-admin' ) . '</option>';
								echo '<option ' . wp_kses_post( wp_unslash( $slider_range ) ) . ' value="slider_range" ' . (( 'slider_range' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? 'selected':'' ) . '>' . esc_html__( 'Range Slider', 'templatic-admin' ) . '</option>';
								echo '</select>';
								echo '</p>';

								/*select option */
								echo "<div class='search_select_" . wp_kses_post( wp_unslash( $key ) ) . " search_select' " . (( 'text' == wp_kses_post( wp_unslash( $ctype ) ) && 'select' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? "style='display:block'":"style='display:none'") . '>';
								echo '<p><label>' . esc_html__( 'Option Title', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $option_title ) ) . '" id="search_option_title" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][option_title]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
								echo '<p><label>' . esc_html__( 'Option values', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $option_values ) ) . '" id="search_option_values" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][option_values]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
								echo '</div>';
								/*End Search title */

								/* Range field related option */
								echo "<div class='range_type_select_" . wp_kses_post( wp_unslash( $key ) ) . " range_type_select' " . (( 'min_max_range_select' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? "style='display:block'":"style='display:none'") . '>';
								echo '<p><label>' . esc_html__( 'Min Option Title', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $min_option_title ) ) . '" id="search_min_option_title" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][min_option_title]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
								echo '<p><label>' . esc_html__( 'Min Option values', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $min_option_values ) ) . '" id="search_min_option_values" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][min_option_values]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
								echo '<p><label>' . esc_html__( 'Max Option Title', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $max_option_title ) ) . '" id="search_max_option_title" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '6[' . wp_kses_post( wp_unslash( $key ) ) . '][max_option_title]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
								echo '<p><label>' . esc_html__( 'Max Option values', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $max_option_values ) ) . '" id="search_mzx_option_values" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][max_option_values]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
								echo '</div>';

								/* Range slider related option */
								echo "<div class='range_type_slider_" . wp_kses_post( wp_unslash( $key ) ) . " range_type_slider' " . (( 'slider_range' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? "style='display:block'":"style='display:none'") . '>';
								echo '<p><label>' . esc_html__( 'Define your range', 'templatic-admin' ) . '</label>';
								echo '<fieldset>
								<input type="text" placeholder="Min value" value="' . wp_kses_post( wp_unslash( $range_min ) ) . '" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][range_min]" id="range_min_value">
								<input type="text" placeholder="max value" value="' . wp_kses_post( wp_unslash( $range_max ) ) . '" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . wp_kses_post( wp_unslash( $key ) ) . '][range_max]" id="range_max_value">
							</fieldset>';
								echo '</p>';
								echo '</div>';
							} // End if().

							echo '<div class="widget-control-actions">';
							echo '<div class="alignleft">';
							echo '<a class="widget-control-remove" href="#remove">' . esc_html__( 'Delete', 'templatic-admin' ) . '</a> | <a class="widget-control-close" href="#close">' . esc_html__( 'Close', 'templatic-admin' ) . '</a>';
							echo '</div><br class="clear" />';

							echo '</div>';/*Finish widget control actionsdiv*/

							echo '</div>';/*Finish widget-inside div*/
					?>
				</div>
				<?php
					} // End foreach().

			endif;/*finish search ctype if condition*/
			?>
		</div>
		<br class="clear">
		<script type="text/javascript" async >
			jQuery(document).ready(function( $) {
				jQuery("#<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'search_custom_fields' ) ) ); ?>").sortable({
					'start': function (event, ui ) {
						/*jQuery Ui-Sortable Overlay Offset Fix*/
						if ( $.browser.webkit ) {
							wscrolltop = $(window).scrollTop();
						}
					},
					'sort': function (event, ui ) {
						if ( $.browser.webkit ) {
							ui.helper.css({ 'top': ui.position.top + wscrolltop + 'px' });
						}
					},
					update: function(e, ui) {
						var widget = jQuery(e.target).closest( 'div.widget' )
						var image_names = '', data_sort='', data_sort_key='';
						var sortable=0;
						/*Sort order loop */
						jQuery("#<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'search_custom_fields' ) ) ); ?> .widget").css( 'cursor', 'default' ).each(function() {
							data_sort=jQuery(this).attr( 'data-sort' );
							/* search custom field sort order assign */
							widget.find( 'form' ).find("input:hidden[name='<?php echo wp_kses_post( wp_unslash( $orderby_customfields ) );?>["+sortable+"]']").val(data_sort);
							sortable++;
						});
						data = widget.find( 'form' ).serialize();
						widget = jQuery(widget);
						jQuery( '.spinner', widget).show();

						jQuery.ajax({
							url: ajaxUrl,
							type: 'POST',
							data:'action=save-widget&savewidgets='+jQuery( '#_wpnonce_widgets' ).val()+'&'+data,
							success:function(result) {
								jQuery( '.spinner' ).hide();
								/*document.getElementById( 'imgarr' ).value = result;*/
							}
						});

					}
				});
});


function show_custom_fields(custom_fields_lists) {
	jQuery("#"+custom_fields_lists+" dd ul").show();
	return false;
}

function add_search_custom_field(value,custom_fields_lists) {
	var cvalue=value;
	jQuery("#"+custom_fields_lists+" dd ul").hide();
	var custom_field_div = custom_fields_lists;
	var custom_field_class = jQuery( '#'+custom_fields_lists).attr( 'data-class' );
	var data_search_order = jQuery( '#'+custom_fields_lists).attr( 'data-order' );

	var html_custom_search='';
	html_custom_search+='<div class="widget open custom_'+custom_field_class+'_'+cvalue+'" id="search_custom_field_'+cvalue+'" data-sort="'+cvalue+'">';
	html_custom_search+='<input type="hidden" name="'+data_search_order+'[]" value="'+cvalue+'" >';
	html_custom_search+=jQuery( '#'+custom_field_div+' ul li div#search_custom_field_'+cvalue).html();
	html_custom_search+='</div>';
	jQuery( "."+custom_field_class).prepend(html_custom_search);
	return false;
}

jQuery(document).bind( 'click', function(e ) {
	var $clicked = jQuery(e.target);
	if ( ! $clicked.parents().hasClass("dropdown" ) )
		jQuery("#<?php echo wp_kses_post( wp_unslash( $this->get_field_id( 'custom_fields_lists' ) ) ); ?> dd ul").hide();
});
</script>
<?php
add_action( 'admin_footer', 'tmpl_advance_searchable_scripts' );
	}
}
/**
 * Templatic advance search widget init.
 */
add_action( 'widgets_init', create_function( '', 'return register_widget("templatic_advanced_search");' ) );


/**
 * Advance serach html
 *
 * @param array $post_types 				Post Type.
 * @param array $search_custom_fields 		Custom fields Array.
 * @param array $search_ctype 				Post type.
 * @param array $search_custom_fields_id 	Search Custom Fields Array.
 * @param array $custom_fields_list_id 		Custom fields id list.
 */
function tmpl_advance_search_custom_fields( $post_types, $search_custom_fields, $search_ctype, $search_custom_fields_id, $custom_fields_list_id ) {

	global $wpdb, $post, $_wp_additional_image_sizes, $sitepress, $search_custom_fields_instance;

	/* Get the search custom fields value from global search custom fields instance variable */
	$search_custom_fields_value = ( $search_custom_fields_instance['search_custom_fields'] ) ? $search_custom_fields_instance['search_custom_fields'] : array();

	$args = array(
		'post_type'   => 'custom_fields',
		'posts_per_page' => -1,
		'post_status'  => array( 'publish' ),
		'post__not_in'  => $remove_post_id_array,
		'meta_query'   => array(
			'relation' => 'AND',
			array(
				'key' => 'post_type_' . $post_types,
				'value' => array(
			'all',
			$post_types,
			),
			'compare' => 'IN',
			'type' => 'text',
			)
			),
		'meta_key'    => $post_types . '_sort_order',
		'orderby'    => 'meta_value_num',
		'meta_value_num' => $post_types . '_sort_order',
		'order'     => 'ASC',
		''
		);

	add_filter( 'posts_join', 'templ_advance_search_custom_fields_where_filter' );

	$post_meta_info = new WP_Query( $args );

	remove_filter( 'posts_join', 'templ_advance_search_custom_fields_where_filter' );

	if ( $post_meta_info->have_posts() ) {
		echo '<dt><a href="#" onclick=\'show_custom_fields("' . wp_kses_post( wp_unslash( $custom_fields_list_id ) ) . '");return false;\'><span>' . esc_html__( 'Add a Search Field', 'templatic-admin' ) . '</span></a></dt>';

		echo '<dd><ul>';
		$i = 0;
		while ( $post_meta_info->have_posts( ) ) : $post_meta_info->the_post();
			$is_active = get_post_meta( $post ->ID, 'is_active',true );
			$ctype = get_post_meta( $post ->ID, 'ctype',true );

			$show_in = apply_filters( 'templ_advance_search_showin_option', get_post_meta( $post->ID, 'show_in_property_search',true ), $post );

			/* Continue Loop on custom field disable or heading type custom fields */
			if ( 1 != $is_active || 'heading_type' == $ctype || 'image_uploader' == $ctype || 'oembed_video' == $ctype || 'coupon_uploader' == $ctype || 'upload' == $ctype ) {
				continue;
			}

			/*Get the custom fields htmlvar_name */
			$htmlvar_name = get_post_meta( $post->ID,'htmlvar_name',true );
			/*Translate custom fields id using icl object id function */
			if ( function_exists( 'icl_object_id' ) ) {
				$icl_post_id = icl_object_id( get_the_ID(), 'post_custom_fields', false );
				$post ->post_title = get_the_title( $icl_post_id );
			}

			if ( 'post_title' != $htmlvar_name && 'post_content' != $htmlvar_name && 'post_excerpt' != $htmlvar_name && '' != $post->post_title ) {
				$checked = ( ! empty( $search_custom_fields_value ) && in_array( get_the_ID(), $search_custom_fields_value ) ) ? 'checked="checked"' : '';

				echo '<li>';
				echo "<label><a href='#' data-value='" . intval( get_the_ID() ) . "' onclick=\"add_search_custom_field(" . intval( get_the_ID() ) . ", '" . wp_kses_post( wp_unslash( $custom_fields_list_id ) ) . "' );return false;\">" . wp_kses_post( wp_unslash( $post ->post_title ) ) . '</a></label>';
				/*echo "<label><input type='checkbox' name='".$search_custom_fields."[".$i++."]' value='".get_the_ID()."' ".$checked."> ".$post->post_title."</label>";*/
				echo '<div class="widget custom_' . intval( $search_custom_fields_id ) . '_' . intval( get_the_ID() ) . ' open" id="search_custom_field_' . intval( get_the_ID() ) . '" style="display:none" data-show="' . wp_kses_post( wp_unslash( $show_in ) ) . '" data-search-id="' . intval( get_the_ID() ) . '">';
				echo '<div class="widget-top">';
				echo '<div class="widget-title-action">
				<a class="widget-action hide-if-no-js" href="#available-widgets"></a>
			</div>';
				echo '<div class="widget-title">';
					echo '<h4>' . wp_kses_post( wp_unslash( $post ->post_title ) ) . '</h4>';
				echo '</div>';/*Finish widget-title div*/
				echo '</div>';/*Finish widget-top div*/

				echo '<div class="widget-inside" style="display: block;">';
				if ( 'post_categories' == $ctype || 'multicity' == $ctype || 'geo_map' == $ctype || 'date' == $ctype ) {

					echo "<input type='hidden' value='" . wp_kses_post( wp_unslash( $ctype ) ) . "' name='" . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . "][search_ctype]'>";
					if ( 'geo_map' == $ctype && is_plugin_active( 'Tevolution-LocationManager/location-manager.php' ) ) {
						$radius_measure = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['radius_measure'] ) ) ?$search_custom_fields_instance['search_ctype'][ get_the_ID() ]['radius_measure']:'';
						$miles_search = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['miles_search'] ) ) ?$search_custom_fields_instance['search_ctype'][ get_the_ID() ]['miles_search']:'';
						echo '<p><label><input name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][miles_search]" type="checkbox" value="1" style="width:10px;" />' . esc_html__( 'Search By Distance?', 'templatic-admin' ) . '</label>';
						echo '<p><label>' . esc_html__( 'Search By', 'templatic-admin' ) . '
				<select name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][radius_measure]">
					<option value="kilometer" ' . (('kilometer' == $radius_measure )? 'selected':'' ) . '>' . esc_html__( 'Kilometers', 'templatic-admin' ) . '</option>
					<option value="miles" ' . (( 'miles' == $radius_measure )? 'selected':'' ) . '>' . esc_html__( 'Miles', 'templatic-admin' ) . '</option>
				</select>
			</p>';
					}
				} else {
					/*Disable search type option */
					$text = $date = $multicheckbox = $radio = $select = $min_max_range = $min_max_range_select = $slider_range = '';
					if ( 'text' == $ctype || 'textarea' == $ctype || 'texteditor' == $ctype ) {
						$date = $multicheckbox = $radio = $select = $min_max_range = $min_max_range_select = $slider_range = 'disabled';
					} elseif ( 'multicheckbox' == $ctype || 'select' == $ctype || 'radio' == $ctype ) {
						$date = $text = $min_max_range = $min_max_range_select = $slider_range = 'disabled';
					} elseif ( 'range_type' == $ctype ) {
						$text = $date = $multicheckbox = $radio = $select = 'disabled';
					}
					if ( 'text' == $ctype ) {
						$select = '';
					}
					/*Get the saved Data */
					$search_ctype_val = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['search_ctype'] ) ) ? $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['search_ctype'] :'';
					if ( '' == $search_ctype_val ) {
						$search_ctype_val = get_post_meta( get_the_ID(), 'search_ctype', true );
					}

					$option_title = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['option_title'] ) ) ? $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['option_title']: '';
					$option_values = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['option_values'] ) ) ? $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['option_values'] : '';

					if ( '' == $option_title && '' == $option_values ) {
						$option_title = get_post_meta( get_the_ID(), 'option_title', true );
						$option_values = get_post_meta( get_the_ID(), 'option_values', true );
					}

					$min_option_title = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['min_option_title'] ) ) ? $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['min_option_title'] : '';
					$min_option_values = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['min_option_values'] ) ) ? $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['min_option_values']:'';
					$max_option_title = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['max_option_title'] ) ) ?$search_custom_fields_instance['search_ctype'][ get_the_ID() ]['max_option_title']:'';
					$max_option_values = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['max_option_values'] ) ) ?$search_custom_fields_instance['search_ctype'][ get_the_ID() ]['max_option_values']:'';
					$range_min = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['range_min'] ) ) ?$search_custom_fields_instance['search_ctype'][ get_the_ID() ]['range_min']:'';
					$range_max = (isset( $search_custom_fields_instance['search_ctype'][ get_the_ID() ]['range_max'] ) ) ?$search_custom_fields_instance['search_ctype'][ get_the_ID() ]['range_max']:'';

					/* value not set */
					if ( '' == $min_option_title && '' == $min_option_values && '' == $max_option_title && '' == $max_option_values ) {
						$min_option_title = get_post_meta( get_the_ID(), 'search_min_option_title', true );
						$min_option_values = get_post_meta( get_the_ID(), 'search_min_option_values', true );
						$max_option_title = get_post_meta( get_the_ID(), 'search_max_option_title', true );
						$max_option_values = get_post_meta( get_the_ID(), 'search_max_option_values', true );
					}

					if ( '' == $range_min && '' == $range_max ) {
						$range_min = get_post_meta( get_the_ID(), 'range_min', true );
						$range_max = get_post_meta( get_the_ID(), 'range_max', true );
					}

					echo '<p><label>' . esc_html__( 'Show on search as', 'templatic-admin' ) . '</label>';
					echo "<select name='" . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . "][search_ctype]' class='search_ctype_" . intval( get_the_ID() ) . " search_custom_ctype' data-post-id='" . intval( get_the_ID() ) . "' onchange='select_search_type_option(this);' 			data-search-type='" . wp_kses_post( wp_unslash( $ctype ) ) . "'>";
					echo '<option value="" >' . esc_html__( 'Select type on search', 'templatic-admin' ) . '</option>';
					echo '<option ' . wp_kses_post( wp_unslash( $text ) ) . ' value="text" ' . (( 'text' == $search_ctype_val ) ? 'selected':'' ) . '>' . esc_html__( 'Text', 'templatic-admin' ) . '</option>';
					/*echo '<option ' . $date. ' value="date">' . esc_html__( 'Date Picker', 'templatic-admin' ). '</option>';*/
					echo '<option ' . wp_kses_post( wp_unslash( $multicheckbox ) ) . ' value="multicheckbox" ' . (( 'multicheckbox' == $search_ctype_val )? 'selected':'' ) . '>' . esc_html__( 'Multi Checkbox', 'templatic-admin' ) . '</option>';
					echo '<option ' . wp_kses_post( wp_unslash( $radio ) ) . ' value="radio" ' . (( 'radio' == $search_ctype_val )? 'selected':'' ) . '>' . esc_html__( 'Radio', 'templatic-admin' ) . '</option>';
					echo '<option ' . wp_kses_post( wp_unslash( $select ) ) . ' value="select" ' . (( 'select' == $search_ctype_val )? 'selected':'' ) . '>' . esc_html__( 'Select', 'templatic-admin' ) . '</option>';
					echo '<option ' . wp_kses_post( wp_unslash( $min_max_range ) ) . ' value="min_max_range" ' . (( 'min_max_range' == $search_ctype_val )? 'selected':'' ) . '>' . esc_html__( 'Min-Max Range (Text)', 'templatic-admin' ) . '</option>';
					echo '<option ' . wp_kses_post( wp_unslash( $min_max_range_select ) ) . ' value="min_max_range_select" ' . (( 'min_max_range_select' == $search_ctype_val )? 'selected':'' ) . '>' . esc_html__( 'Min-Max Range (Select)', 'templatic-admin' ) . '</option>';
					echo '<option ' . wp_kses_post( wp_unslash( $slider_range ) ) . ' value="slider_range" ' . (( 'slider_range' == $search_ctype_val )? 'selected':'' ) . '>' . esc_html__( 'Range Slider', 'templatic-admin' ) . '</option>';
					echo '</select>';
					echo '</p>';

					/*select option */
					echo "<div class='search_select_" . intval( get_the_ID() ) . " search_select' " . (( 'text' == wp_kses_post( wp_unslash( $ctype ) ) && 'select' == wp_kses_post( wp_unslash( $search_ctype_val ) ) )? "style='display:block'":"style='display:none'") . '>';
					echo '<p><label>' . esc_html__( 'Option Title', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $option_title ) ) . '" id="search_option_title" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][option_title]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
					echo '<p><label>' . esc_html__( 'Option values', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $option_values ) ) . '" id="search_option_values" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][option_values]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
					echo '</div>';
					/*End Search title */

					/* Range field related option */
					echo "<div class='range_type_select_" . intval( get_the_ID() ) . " range_type_select' " . (( 'min_max_range_select' == $search_ctype_val )? "style='display:block'":"style='display:none'") . '>';
					echo '<p><label>' . esc_html__( 'Min Option Title', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $min_option_title ) ) . '" id="search_min_option_title" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][min_option_title]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
					echo '<p><label>' . esc_html__( 'Min Option values', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $min_option_values ) ) . '" id="search_min_option_values" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][min_option_values]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
					echo '<p><label>' . esc_html__( 'Max Option Title', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $max_option_title ) ) . '" id="search_max_option_title" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][max_option_title]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
					echo '<p><label>' . esc_html__( 'Max Option values', 'templatic-admin' ) . '</label><input type="text" size="41" value="' . wp_kses_post( wp_unslash( $max_option_values ) ) . '" id="search_mzx_option_values" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][max_option_values]"><span class="clearfix description">' . esc_html__( 'Separate multiple option titles with a comma. eg. Yes,No', 'templatic-admin' ) . '</span></p>';
					echo '</div>';

					/* Range slider related option */
					echo "<div class='range_type_slider_" . get_the_ID() . " range_type_slider' " . (( 'slider_range' == $search_ctype_val )? "style='display:block'":"style='display:none'") . '>';
					echo '<p><label>' . esc_html__( 'Define your range', 'templatic-admin' ) . '</label>';
					echo '<fieldset>
		<input type="text" placeholder="Min value" value="' . wp_kses_post( wp_unslash( $range_min ) ) . '" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][range_min]" id="range_min_value">
		<input type="text" placeholder="max value" value="' . wp_kses_post( wp_unslash( $range_max ) ) . '" name="' . wp_kses_post( wp_unslash( $search_ctype ) ) . '[' . intval( get_the_ID() ) . '][range_max]" id="range_max_value">
	</fieldset>';
					echo '</p>';
					echo '</div>';
				} // End if().

				echo '<div class="widget-control-actions">';
				echo '<div class="alignleft">';
				echo '<a class="widget-control-remove" href="#remove">' . esc_html__( 'Delete', 'templatic-admin' ) . '</a> | <a class="widget-control-close" href="#close">' . esc_html__( 'Close', 'templatic-admin' ) . '</a>';
				echo '</div><br class="clear" />';
				echo '</div>';/*Finish widget control actionsdiv*/
				echo '</div>';/*Finish widget-inside div*/

				echo '</div>';/*Finish main widget div*/
				echo '</li>';
			} // End if().
endwhile;
		echo '</ul></dd>';
	} // End if().
}

add_action( 'wp_ajax_tmpl_advance_search_custom_fields', 'tmpl_advance_searchcustomfields' );
/**
 * Hook call for get the post type wise custom fields display.
 */
function tmpl_advance_searchcustomfields() {

	if ( isset( $_REQUEST['post_types'] ) ) {
		$post_types = wp_kses_post( wp_unslash( $_REQUEST['post_types'] ) );
	}
	if ( isset( $_REQUEST['search_custom_fields'] ) ) {
		$search_custom_fields = wp_kses_post( wp_unslash( $_REQUEST['search_custom_fields'] ) );
	}
	if ( isset( $_REQUEST['search_ctype'] ) ) {
		$search_ctype = wp_kses_post( wp_unslash( $_REQUEST['search_ctype'] ) );
	}
	if ( isset( $_REQUEST['search_custom_fields_id'] ) ) {
		$search_custom_fields_id = wp_kses_post( wp_unslash( $_REQUEST['search_custom_fields_id'] ) );
	}
	if ( isset( $_REQUEST['custom_fields_list_id'] ) ) {
		$custom_fields_list_id = wp_kses_post( wp_unslash( $_REQUEST['custom_fields_list_id'] ) );
	}

	echo wp_kses_post( wp_unslash( tmpl_advance_search_custom_fields( $post_types, $search_custom_fields, $search_ctype, $search_custom_fields_id, $custom_fields_list_id ) ) );

	exit;
}

/** Add advance search widget script for display post type wise custom fields and hide show search type option */
function tmpl_advance_searchable_scripts() {
	?>
	<script type="text/javascript" async >
		function tmpl_search_post_type(str,id,search_custom_fields,search_ctype,search_custom_fields_id,custom_fields_list_id) {

			if ( confirm( "<?php echo esc_html__( 'Changing postype will reset search fields below !', 'templatic-admin' );?>" ) ) {
				var post_types=str.value;
				jQuery.ajax({
					url:ajaxUrl,
					type:'POST',
					data:'action=tmpl_advance_search_custom_fields&post_types=' + post_types+'&search_custom_fields='+search_custom_fields+'&search_ctype='+search_ctype+'&search_custom_fields_id='+search_custom_fields_id+'&custom_fields_list_id='+custom_fields_list_id,
					success:function(results ) {
						jQuery( '#'+id).html( '' );
						jQuery( '#'+id).html(results);
						jQuery( '#'+search_custom_fields_id).html( '' );
						jQuery( '#'+id+' dd ul li div.widget' ).each(function( ) {
							if ( jQuery(this).attr( 'data-show' )==1) {
								var cvalue=jQuery(this).attr( 'data-search-id' );
								var custom_field_div = custom_fields_list_id;
								var custom_field_class = jQuery( '#'+custom_fields_list_id).attr( 'data-class' );
								var data_search_order = jQuery( '#'+custom_fields_list_id).attr( 'data-order' );

								var html_custom_search='';
								html_custom_search+='<div class="widget custom_'+custom_field_class+'_'+cvalue+'" id="search_custom_field_'+cvalue+'" data-sort="'+cvalue+'">';
								html_custom_search+='<input type="hidden" name="'+data_search_order+'[]" value="'+cvalue+'" >';
								html_custom_search+=jQuery( '#'+id+' dd ul li div#search_custom_field_'+cvalue).html();
								html_custom_search+='</div>';
								jQuery( '. '+custom_field_class).append(html_custom_search);
								jQuery( '. '+custom_field_class+' div.widget div.widget-inside' ).hide();
							}

						});

					}
				});
return true;
}
else
{
	return false;
}
}

function select_search_type_option(str) {
	var select_value=str.value;
	var data_post_id=jQuery( "select[name='"+str.name+"']" ).attr( 'data-post-id' );

	var data_search_type=jQuery( "select[name='"+str.name+"']" ).attr( 'data-search-type' );


	if ( select_value=='min_max_range' ) {
		jQuery( '.range_type_select_'+data_post_id).hide();
		jQuery( '.range_type_slider_'+data_post_id).hide();
		jQuery( '.search_select_'+data_post_id).hide();
	}else if ( select_value=='min_max_range_select' ) {
		jQuery( '.range_type_select_'+data_post_id).show();
		jQuery( '.range_type_slider_'+data_post_id).hide();
		jQuery( '.search_select_'+data_post_id).hide();
	}else if ( select_value=='slider_range' ) {
		jQuery( '.range_type_select_'+data_post_id).hide();
		jQuery( '.range_type_slider_'+data_post_id).show();
		jQuery( '.search_select_'+data_post_id).hide();
	}else if ( select_value=='select' && data_search_type=='text' ) {
		jQuery( '.search_select_'+data_post_id).show();
	} else {
		jQuery( '.range_type_select_'+data_post_id).hide();
		jQuery( '.range_type_slider_'+data_post_id).hide();
		jQuery( '.search_select_'+data_post_id).hide();
	}
}
</script>
<?php
}

add_action( 'wp_footer', 'tmpl_showsearch_custom_field' );
if ( ! function_exists( 'tmpl_showsearch_custom_field' ) ) {
	/**
	 * Action for to fetch custom field ajax.
	 */
	function tmpl_showsearch_custom_field() {
		global $wp_locale, $search_id, $is_category;
		if ( $is_category ) {
			?>
			<script>
				var jsonString = '<?php echo wp_kses_post( wp_unslash( $search_id ) ); ?>';
				var category_ajax=null;
				jQuery(document).on( 'change', "input[name^='category'], input[name='selectall'], select[name^='category']", function (e ) {
					jQuery( '.form_front_style' ).addClass( 'loading_search_custom_field' );
					var category_id=jQuery( '#category option:selected' ).val();
					var post_type = jQuery( '#post_type' ).val();
					var submit_from = jQuery( 'form#searchform' ).serialize();
					/* Add class custom fields load to display image loader */
					category_ajax =jQuery.ajax({
						url:ajaxUrl,
						type:'POST',
						data:submit_from+'&action=tmpl_advance_search_category_custom_fields&category_id='+category_id+'&post_type='+post_type+'&instance='+jsonString,
						beforeSend : function() {
							if ( category_ajax != null) {
								category_ajax.abort();
							}
						},
						success:function(results) {
							jQuery( '#search_result' ).html(results);
							jQuery( '.form_front_style' ).removeClass( 'loading_search_custom_field' );
						}
					});
				});
			</script>
			<?php
		}
	}
} // End if().

add_action( 'wp_ajax_nopriv_tmpl_advance_search_category_custom_fields', 'tmpl_advance_search_category_custom_fields' );
add_action( 'wp_ajax_tmpl_advance_search_category_custom_fields' , 'tmpl_advance_search_category_custom_fields' );
if ( ! function_exists( 'tmpl_advance_search_category_custom_fields' ) ) {
	/**
	 * Custom field ajax show result.
	 */
	function tmpl_advance_search_category_custom_fields() {
		global $search_instance;

		$adv_search_widget = get_option( 'widget_templatic_advanced_search' );

		$post_type = empty( $adv_search_widget[ $_REQUEST['instance'] ]['post_type'] ) ? 'post' : apply_filters( 'widget_post_type', $adv_search_widget[ $_REQUEST['instance'] ]['post_type'] );
		$orderby_customfields = empty( $adv_search_widget[ $_REQUEST['instance'] ]['orderby_customfields'] ) ? array() : apply_filters( 'widget_orderby_customfields', array_unique( $adv_search_widget[ $_REQUEST['instance'] ]['orderby_customfields'] ) );

		$taxonomies = get_object_taxonomies( (object) array(
			'post_type' => $post_type,
			'public' => true,
			'_builtin' => true,
			)
		);
		$taxonomy = $taxonomies[0];

		if ( ! empty( $orderby_customfields ) && is_array( $orderby_customfields ) ) {

			foreach ( $orderby_customfields as $value ) {

				$ctype = get_post_meta( $value, 'ctype', true );
				if ( 'post_categories' == $ctype ) {
					continue;
				}

				$terms = wp_get_post_terms( $value, $taxonomy );

				foreach ( $terms as $term_single ) {

					if ( isset( $_REQUEST['category_id'] ) && $term_single->term_id == $_REQUEST['category_id'] ) {
						display_search_widget_custom_post_fields( $value,$adv_search_widget[ wp_kses_post( wp_unslash( $_REQUEST['instance'] ) ) ],1 );
					}
				}
			} // End foreach().
		} // End if().
		exit;
	}
} // End if().

$show_label = apply_filters( 'tmpl_show_searchfields_label', 1 );
/**
 * Display search widget custom fields as per selected custom field on advance search widget.
 *
 * @param integer $value 		Post id.
 * @param array   $instance 	Widget Instacnes.
 * @param string  $show_label 	Want to show label of custom field on frotn end.
 */
function display_search_widget_custom_post_fields( $value, $instance, $show_label ) {
	$htmlvar_name = get_post_meta( $value, 'htmlvar_name', true );

	$show_label = apply_filters( 'tmpl_show_label', $show_label );

	if ( '' != $instance['search_ctype'][ $value ]['option_values'] && '' != $instance['search_ctype'][ $value ]['option_title'] ) {
		$option_values = explode( ',', $instance['search_ctype'][ $value ]['option_values'] );
		$option_title = explode( ',', $instance['search_ctype'][ $value ]['option_title'] );
	} else {
		$option_values = explode( ',', get_post_meta( $value, 'option_values', true ) );
		$option_title = explode( ',', get_post_meta( $value, 'option_title', true ) );
	}
	$site_title = $label = get_the_title( $value );

	if ( function_exists( 'icl_object_id' ) ) {
		$icl_post_id = icl_object_id( $value, 'post_custom_fields', true );
		$site_title = $label = get_the_title( $icl_post_id );
	}

	$type = ( '' != $instance['search_ctype'][ $value ]['search_ctype'] ) ? $instance['search_ctype'][ $value ]['search_ctype'] : get_post_meta( $value, 'ctype', true );

	$post_type = $instance['post_type'];

	$val['range_min'] = (@$instance['search_ctype'][ $value ]['range_min'] )?$instance['search_ctype'][ $value ]['range_min'] :'';
	$val['range_max'] = (@$instance['search_ctype'][ $value ]['range_max'] )? $instance['search_ctype'][ $value ]['range_max'] :'';

	$style_class = get_post_meta( $value, 'style_class', true );
	$extra_parameter = get_post_meta( $value, 'extra_parameter', true );
	$default = get_post_meta( $value,'default_value',true );
	$radio_type = '';
	if ( 'radio' == $type ) {
		$radio_type = '_radio';
	}

	?>
	<input type="hidden" name="search_custom[<?php echo wp_kses_post( wp_unslash( $htmlvar_name . $radio_type ) );?>]" value="<?php echo wp_kses_post( wp_unslash( $type ) );?>" />
	<?php
	if ( 'post_categories' == $type ) {

		/*fetch the categories of selected post type */
		$taxonomies = get_object_taxonomies( (object) array(
			'post_type' => $post_type,
			'public'  => true,
			'_builtin' => true,
			)
		);
		$args = array(
			'show_option_all'  => __( 'Select Category', 'templatic' ),
			'show_option_none'  => '',
			'orderby'      => 'name',
			'order'       => 'ASC',
			'show_count'     => 0,
			'hide_empty'     => 1,
			'child_of'      => 0,
			'echo'        => 1,
			'selected'      => 0,
			'hierarchical'    => 1,
			'name'        => 'category',
			'tab_index'     => 0,
			'taxonomy'      => $taxonomies[0],
			'hide_if_empty'   => false,
			);

		echo '<div class="form_row clearfix">';
		if ( apply_filters( 'tmpl_searchfrm_category_hook', $label ) == '[#taxonomy_name#]' ) {
			$labal = 'Locations & Map';
		} else {
			$labal = apply_filters( 'tmpl_searchfrm_category_hook', $label );
		}
		if ( 1 == $show_label ) { ?><label class="r_lbl"><?php echo wp_kses_post( wp_unslash( $labal ) ); ?></label> <?php }
		wp_dropdown_categories( $args );
		echo '</div>';

	} elseif ( 'text' == $type || 'geo_map' == $type || 'texteditor' == $type || 'textarea' == $type ) {

		echo '<div class="form_row clearfix ' . (( isset( $instance['search_ctype'][ $value ]['miles_search'] ) && 1 == $instance['search_ctype'][ $value ]['miles_search'])? 'address_search' :'' ) . '">';

		if ( 1 == $show_label ) { ?><label class="r_lbl"><?php echo wp_kses_post( wp_unslash( $label ) ); ?></label> <?php }
		if ( isset( $_REQUEST[ $htmlvar_name ] ) ) {
			$htmlvar_name_val = wp_kses_post( wp_unslash( $_REQUEST[ $htmlvar_name ] ) );
		}
		echo '<input type="text" name="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '" value="' . wp_kses_post( wp_unslash( $htmlvar_name_val ) ) . '" placeholder="' . wp_kses_post( wp_unslash( $label ) ) . '" class="textfield ' . wp_kses_post( wp_unslash( $style_class ) ) . '" ' . wp_kses_post( wp_unslash( $extra_parameter ) ) . ' />';

		/* Display within radius field on geo_map custom field type */
		if ( 'geo_map' == $type && 1 == $instance['search_ctype'][ $value ]['miles_search'] ) {
			$radius_measure = $instance['search_ctype'][ $value ]['radius_measure'];
			$radius_type = ( 'miles' == $radius_measure )? __( 'Miles', 'templatic' ) : __( 'Kilometers', 'templatic' );
			?>
			<select id="radius" name="radius">
				<option value=''><?php esc_html_e( 'Within?', 'templatic' ); ?></option>
				<option value="1" <?php if ( isset( $distance_factor ) && esc_attr( $distance_factor ) == '1' ) { echo 'selected="selected"';} ?>>1 <?php echo ( $radius_measure == 'miles' )? __( 'Mile', 'templatic' ) : __( 'Kilometer', 'templatic' ); ?></option>
				<option value="5" <?php if ( isset( $distance_factor ) && esc_attr( $distance_factor ) == '5' ) { echo 'selected="selected"';} ?>>5 <?php echo wp_kses_post( wp_unslash( $radius_type ) ); ?></option>
				<option value="10" <?php if ( isset( $distance_factor ) && esc_attr( $distance_factor ) == '10' ) { echo 'selected="selected"';} ?>>10 <?php echo wp_kses_post( wp_unslash( $radius_type ) ); ?></option>
				<option value="100" <?php if ( isset( $distance_factor ) && esc_attr( $distance_factor ) == '100' ) { echo 'selected="selected"';} ?>>100 <?php echo wp_kses_post( wp_unslash( $radius_type ) ); ?></option>
				<option value="1000" <?php if ( isset( $distance_factor ) && esc_attr( $distance_factor ) == '1000' ) { echo 'selected="selected"';} ?>>1000 <?php echo wp_kses_post( wp_unslash( $radius_type ) ); ?></option>
				<option value="5000" <?php if ( isset( $distance_factor ) && esc_attr( $distance_factor ) == '5000' ) { echo 'selected="selected"';} ?>> 5000 <?php echo wp_kses_post( wp_unslash( $radius_type ) ); ?></option>
			</select>
			<input type="hidden" name="radius_type" value="<?php echo wp_kses_post( wp_unslash( $radius_measure ) )?>" />
			<?php
		} // End if().

		echo '</div>';
	} elseif ( 'date' == $type ) {
		?>
		<script type="text/javascript" async >
			jQuery(function() {
				var pickerOpts = {
					showOn: "both",
					dateFormat: 'yy-mm-dd',
					buttonText: '<i class="fa fa-calendar"></i>',
					monthNames: objectL11tmpl.monthNames,
					monthNamesShort: objectL11tmpl.monthNamesShort,
					dayNames: objectL11tmpl.dayNames,
					dayNamesShort: objectL11tmpl.dayNamesShort,
					dayNamesMin: objectL11tmpl.dayNamesMin,
					isRTL: objectL11tmpl.isRTL,
				};
				jQuery( "#tmpl_search_<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>" ).datepicker( pickerOpts );
			});
		</script>
		<div class="form_row clearfix">
			<input type="text" name="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>" id="tmpl_search_<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>" placeholder="<?php echo wp_kses_post( wp_unslash( $label ) );?>" class="textfield <?php echo wp_kses_post( wp_unslash( $style_class ) );?>" value="" size="25" />
		</div>
		<?php
	} elseif ( 'radio' == $type ) {

		if ( empty( $option_title ) || $option_title == '' ) {
			$option_titles = $option_values;
		}
		?>
		<div class="form_row clearfix">
			<label class="r_lbl"><?php echo wp_kses_post( wp_unslash( $label ) ); ?></label>
			<?php if ( ! empty( $option_values ) && is_array( $option_values ) ) {
				$chkcounter = 0;
				echo '<div class="form_cat_left">';
				echo '<ul class="hr_input_radio">';
				$option_values_count = count( $option_values );
				for ( $i = 0;$i < $option_values_count;$i ++ ) {
					if ( '' == $option_values [ $i ] ) { continue;
					}
					$chkcounter++;
					$seled = '';
					if ( $default_value == $option_values[ $i ] ) { $seled = 'checked="checked"';}
					if ( isset( $value ) && trim( $value ) == trim( $option_values[ $i ] ) ) { $seled = 'checked="checked"';}
					echo '<li>

					<input name="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '_radio" id="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '_' . wp_kses_post( wp_unslash( $chkcounter ) ) . '" type="radio" value="' . wp_kses_post( wp_unslash( trim( $option_values[ $i ] ) ) ) . '" ' . wp_kses_post( wp_unslash( $seled ) ) . ' ' . wp_kses_post( wp_unslash( $extra_parameter ) ) . ' /> <label class="r_lbl" for="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '_' . wp_kses_post( wp_unslash( $chkcounter ) ) . '">' . wp_kses_post( wp_unslash( $option_title[ $i ] ) ) . '</label>
				</li>';
				}
				echo '</ul></div>';

}?>
	</div>
	<?php
	} elseif ( 'multicheckbox' == $type ) {
		if ( empty( $option_title ) || $option_title == '' ) {
			$option_titles = $option_values;
		}
	?>
	<div class="form_row clearfix">
		<label class="r_lbl"><?php echo wp_kses_post( wp_unslash( $label ) ); ?></label>
		<?php if ( ! empty( $option_values ) && is_array( $option_values ) ) {
			$chkcounter = 0;
			echo '<div class="form_cat_left hr_input_multicheckbox">';
			$option_values_count = count( $option_values );
			for ( $i = 0;$i < $option_values_count;$i ++ ) {
				if ( '' == $option_values[ $i ] ) { continue;
				}
				$chkcounter++;
				$seled = '';
				if ( $default_value == $option_values[ $i ] ) { $seled = 'checked="checked"';}
				if ( isset( $value ) && trim( $value ) == trim( $option_values[ $i ] ) ) { $seled = 'checked="checked"';}
				echo '<div class="form_cat">

				<input name="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '[]" id="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '_' . wp_kses_post( wp_unslash( $chkcounter ) ) . '" type="checkbox" value="' . wp_kses_post( wp_unslash( trim( $option_values[ $i ] ) ) ) . '" ' . wp_kses_post( wp_unslash( $seled ) ) . ' ' . wp_kses_post( wp_unslash( $extra_parameter ) ) . ' /> <label class="r_lbl" for="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '_' . wp_kses_post( wp_unslash( $chkcounter ) ) . '">' . wp_kses_post( wp_unslash( $option_title[ $i ] ) ) . '</label>
			</div>';
			}
			echo '</div>';

}?>
</div>
<?php

	} elseif ( 'select' == $type ) {
		if ( empty( $option_title ) || $option_title == '' ) {
			$option_titles = $option_values;
		}
	?>
	<div class="form_row clearfix">
		<?php if ( 1 == $show_label ) { ?>
			<label class="r_lbl"><?php echo wp_kses_post( wp_unslash( $label ) ); ?></label>
		<?php
}
if ( ! empty( $option_values ) && is_array( $option_values ) ) {
		$chkcounter = 0;
		echo '<div class="select">';
		echo '<select name="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '" id="' . wp_kses_post( wp_unslash( $htmlvar_name ) ) . '" class="textfield textfield_x ' . wp_kses_post( wp_unslash( $style_class ) ) . ' select" ' . wp_kses_post( wp_unslash( $extra_parameter ) ) . '>';
		echo '<option value="">' . sprintf( esc_html__( 'Please Select %s', 'templatic' ), wp_kses_post( wp_unslash( $label ) ) ) . '</option>';
		$option_values_count = count( $option_values );
	for ( $i = 0; $i < $option_values_count;$i ++ ) {
		if ( '' == $option_values[ $i ] ) { continue;
		}
			$chkcounter++;
			$seled = '';
		if ( $default_value == $option_values[ $i ] ) { $seled = 'checked="checked"';}
		if ( isset( $value ) && trim( $value ) == trim( $option_values[ $i ] ) ) { $seled = 'checked="checked"';}

			echo '<option value="' . wp_kses_post( wp_unslash( trim( $option_values[ $i ] ) ) ) . '" >' . wp_kses_post( wp_unslash( $option_title[ $i ] ) ) . '</option>';
	}
		echo '</select></div>';

}?>
</div>
<?php
	} elseif ( 'min_max_range' == $type ) {
	?>
	<div class="form_row clearfix">
		<div class="half_row clearfix">
			<input type="text" name="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) ) . '_min';?>" id="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_min" value="" placeholder="<?php if ( $show_label == 0 ) { echo wp_kses_post( wp_unslash( $site_title ) ) . ' ';
				esc_html_e( 'Min value', 'templatic' ); } ?>" class="min_range" onfocus="if ( this.placeholder == '<?php echo wp_kses_post( wp_unslash( $site_title ) ) . ' ';
esc_html_e( 'Min value', 'templatic' ); ?>' ) {this.placeholder = '';}" onblur="if ( this.placeholder == '' ) {this.placeholder = '<?php echo wp_kses_post( wp_unslash( $site_title ) ) . ' ';
esc_html_e( 'Min value', 'templatic' ); ?>';}"/>
		</div>
		<div class="half_row clearfix">
			<input type="text" name="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) ) . '_max';?>" id="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_max" value="" placeholder="<?php if ( $show_label == 0 ) { echo wp_kses_post( wp_unslash( $site_title ) ) . ' ';
				esc_html_e( 'Max value', 'templatic' ); } ?>" class="max_range" onfocus="if ( this.placeholder == '<?php echo wp_kses_post( wp_unslash( $site_title ) ) . ' ';
esc_html_e( 'Max value', 'templatic' ); ?>' ) {this.placeholder = '';}" onblur="if ( this.placeholder == '' ) {this.placeholder = '<?php echo wp_kses_post( wp_unslash( $site_title ) ) . ' ';
esc_html_e( 'Max value', 'templatic' ); ?>';}"/>
		</div>
	</div>
	<?php
	} elseif ( 'slider_range' == $type && '' != $instance['search_ctype'][ $value ]['range_min'] && '' != $instance['search_ctype'][ $value ]['range_max'] ) {
		$min_range = $val['range_min'];
		$max_range = $val['range_max'];

		wp_enqueue_script( 'jquery-ui-slider' );
	?>
	<div class="form_row clearfix">
		<label class="r_lbl"><?php echo wp_kses_post( wp_unslash( $site_title ) ); ?></label>

		<input type="text" name="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>" id="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_range" value="<?php echo wp_kses_post( wp_unslash( $max_range ) ); ?>" style="border:0; font-weight:bold;" readonly="readonly"/>
	</label>
	<div id="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_range_type" class="clearfix" style="width:95%;"></div>
	<script type="text/javascript" async >
		jQuery(function() {jQuery("#<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) )?>_range_type").slider({range:true,min:<?php echo wp_kses_post( wp_unslash( $min_range ) );?>,max:<?php echo wp_kses_post( wp_unslash( $max_range ) ); ?>,values:[<?php echo wp_kses_post( wp_unslash( $min_range ) );?>,<?php echo wp_kses_post( wp_unslash( $max_range ) ); ?>],slide:function(e,t) {jQuery("#<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_range").val(t.values[0]+" - "+t.values[1] )}});jQuery("#<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_range").val(jQuery("#<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) )?>_range_type").slider("values",0)+" - "+jQuery("#<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) )?>_range_type").slider("values",1 ) ) })
	</script>
</div>
<?php
	} elseif ( 'min_max_range_select' == $type && '' != $instance['search_ctype'][ $value ]['min_option_title'] && '' != $instance['search_ctype'][ $value ]['min_option_values'] && '' != $instance['search_ctype'][ $value ]['max_option_title'] && '' != $instance['search_ctype'][ $value ]['max_option_values'] ) {
		$title_min_range = explode( ',', $instance['search_ctype'][ $value ]['min_option_title'] );
		$value_min_range = explode( ',', $instance['search_ctype'][ $value ]['min_option_values'] );
		$title_max_range = explode( ',', $instance['search_ctype'][ $value ]['max_option_title'] );
		$value_max_range = explode( ',', $instance['search_ctype'][ $value ]['max_option_values'] );
	?>
	<div class="form_row clearfix">
		<div class="selectbox">
			<select name="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_min" id="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_min" class="textfield textfield_x <?php echo wp_kses_post( wp_unslash( $style_class ) );?> select" <?php echo wp_kses_post( wp_unslash( $extra_parameter ) );?>>
				<option value=""><?php echo sprintf( esc_html__( 'Please Select %s Min value', 'templatic' ), wp_kses_post( wp_unslash( $site_title ) ) );?></option>
				<?php if ( ! empty( $value_min_range ) ) {
					$value_min_range_count = count( $value_min_range );
					for ( $i = 0;$i < $value_min_range_count;$i ++ ) {?>
					<option value="<?php echo wp_kses_post( wp_unslash( $value_min_range[ $i ] ) ); ?>" <?php if ( $value == $value_min_range[ $i ] ) { echo 'selected="selected"';
} elseif ( $default_value == $value_min_range[ $i ] ) { echo 'selected="selected"';}?>><?php echo ( $title_min_range[ $i ] )? wp_kses_post( wp_unslash( $title_min_range[ $i ] ) ) : wp_kses_post( wp_unslash( $value_min_range[ $i ] ) ); ?></option>
					<?php
					}
}?>
		</select>
	</div>
</div>

<div class="form_row clearfix">
	<div class="selectbox">
		<select name="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_max" id="<?php echo wp_kses_post( wp_unslash( $htmlvar_name ) );?>_max" class="textfield textfield_x <?php echo wp_kses_post( wp_unslash( $style_class ) );?> select" <?php echo wp_kses_post( wp_unslash( $extra_parameter ) );?>>
			<option value=""><?php echo sprintf( esc_html__( 'Please Select %s Max value', 'templatic' ), wp_kses_post( wp_unslash( $site_title ) ) );?></option>
			<?php if ( ! empty( $value_max_range ) ) {
				$value_max_range_count = count( $value_max_range );
				for ( $i = 0;$i < $value_max_range_count;$i ++ ) {?>
				<option value="<?php echo wp_kses_post( wp_unslash( $value_max_range[ $i ] ) ); ?>" <?php if ( $value == $value_max_range[ $i ] ) { echo 'selected="selected"';
} elseif ( $default_value == $value_max_range[ $i ] ) { echo 'selected="selected"';}?>><?php echo ( $title_max_range[ $i ] )? wp_kses_post( wp_unslash( $title_max_range[ $i ] ) ) : wp_kses_post( wp_unslash( $value_max_range[ $i ] ) ); ?></option>
				<?php
				}
}?>
	</select>
</div>
</div>
<?php

	} else {
		$val['name'] = $htmlvar_name;
		$val['label'] = $label;
		$val['type'] = $type;
		$val['htmlvar_name'] = $htmlvar_name;
		$val['option_values'] = $option_values;
		$val['option_title'] = $option_title;
		$val['default'] = $default;
		$val['style_class'] = $style_class;
		$val['extra_parameter'] = $extra_parameter;

		/* Add advancesearch_custom_fieldtype hook for add additinal search html on frontend*/
		do_action( 'advancesearch_custom_fieldtype', $htmlvar_name, $val, $post_type );
	} // End if().
}

/**
 * Where filter for advance search with wpml
 *
 * @param string $join 		Join query for wpml.
 */
function templ_advance_search_custom_fields_where_filter( $join ) {
	global $wpdb, $pagenow, $wp_taxonomies, $ljoin, $sitepress;
	$language_where = '';
	if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
		$language = $sitepress->get_default_language();
		$join .= " {$ljoin} JOIN {$wpdb->prefix}icl_translations t ON {$wpdb->posts}.ID = t.element_id
		AND t.element_type IN ( 'post_custom_fields' ) JOIN {$wpdb->prefix}icl_languages l ON t.language_code=l.code AND l.active=1 AND t.language_code='" . $language . "'";
	}
	return $join;
}
?>
